@@ -111,7 +111,6 @@ struct _VteTerminalClass {
 };
 
 /* The structure we return as the supplemental attributes for strings. */
-typedef struct _VteCharAttributes VteCharAttributes;
 struct _VteCharAttributes {
         /*< private >*/
 	long row, column;
@@ -171,6 +170,11 @@ void vte_terminal_paste_primary(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 void vte_terminal_select_all(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 void vte_terminal_unselect_all(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
 
+/* By-word selection */
+void vte_terminal_set_word_char_exceptions(VteTerminal *terminal,
+                                           const char *word_char_exceptions) _VTE_GNUC_NONNULL(1);
+const char *vte_terminal_get_word_char_exceptions(VteTerminal *terminal) _VTE_GNUC_NONNULL(1);
+
 /* Set the terminal's size. */
 void vte_terminal_set_size(VteTerminal *terminal,
 			   glong columns, glong rows) _VTE_GNUC_NONNULL(1);
@@ -283,9 +287,6 @@ int vte_terminal_match_add_gregex(VteTerminal *terminal,
                                   GRegex *regex,
                                   GRegexMatchFlags flags) _VTE_GNUC_NONNULL(1);
 /* Set the cursor to be used when the pointer is over a given match. */
-void vte_terminal_match_set_cursor(VteTerminal *terminal,
-                                   int tag,
-				   GdkCursor *cursor) _VTE_GNUC_NONNULL(1);
 void vte_terminal_match_set_cursor_type(VteTerminal *terminal,
 					int tag,
                                         GdkCursorType cursor_type) _VTE_GNUC_NONNULL(1);
